import React from "react";
import { Link, useLocation } from "wouter";
import { 
  LayoutDashboard, 
  ClipboardList, 
  PlusCircle, 
  BarChart3, 
  Settings, 
  X,
  Upload,
  FileUp
} from "lucide-react";
import logo from "@assets/logo.png";
import { Button } from "@/components/ui/button";
import { cn } from "@/lib/utils";

interface SidebarProps {
  onClose?: () => void;
}

export default function Sidebar({ onClose }: SidebarProps) {
  const [location] = useLocation();

  const navItems = [
    { icon: LayoutDashboard, label: "Dashboard", path: "/" },
    { icon: ClipboardList, label: "Incidents", path: "/incidents" },
    { icon: PlusCircle, label: "New Incident", path: "/incidents/new" },
    { icon: FileUp, label: "Import Data", path: "/import" },
    { icon: BarChart3, label: "Reports", path: "/reports" },
    { icon: Settings, label: "Settings", path: "/settings" },
  ];

  const isActive = (path: string) => {
    if (path === "/" && location === "/") return true;
    if (path !== "/" && location.startsWith(path)) return true;
    return false;
  };

  return (
    <div className="flex flex-col h-full bg-white border-r border-neutral-200 shadow-sm">
      <div className="p-4 border-b border-neutral-200 flex flex-col items-center">
        <div className="flex w-full items-center justify-between mb-2">
          <h1 className="text-xl font-semibold text-neutral-800">Basingstoke Station Incident Management Tool 2025</h1>
          <Button 
            variant="ghost" 
            size="icon" 
            className="md:hidden" 
            onClick={onClose}
          >
            <X className="h-5 w-5" />
            <span className="sr-only">Close</span>
          </Button>
        </div>
        <div className="flex justify-center w-full px-2">
          <img 
            src={logo} 
            alt="Hampshire & Isle of Wight Fire & Rescue Service" 
            className="w-40 h-auto my-3" 
          />
        </div>
      </div>
      
      <nav className="flex-1 p-4 space-y-1">
        {navItems.map((item) => (
          <div key={item.path} className="w-full">
            <Link 
              href={item.path}
              onClick={onClose}
            >
              <div
                className={cn(
                  "flex items-center px-4 py-2 text-sm font-medium rounded-md transition-colors cursor-pointer",
                  isActive(item.path)
                    ? "text-white bg-primary"
                    : "text-neutral-600 hover:bg-neutral-100"
                )}
              >
                <item.icon className={cn("mr-3 h-5 w-5", isActive(item.path) ? "text-white" : "text-neutral-400")} />
                {item.label}
              </div>
            </Link>
          </div>
        ))}
      </nav>
      
      <div className="p-4 border-t border-neutral-200">
        <div className="flex items-center">
          <div className="h-8 w-8 rounded-full bg-primary flex items-center justify-center text-white font-medium">
            JD
          </div>
          <div className="ml-3">
            <p className="text-sm font-medium text-neutral-800">John Doe</p>
            <p className="text-xs text-neutral-600">Station Officer</p>
          </div>
        </div>
      </div>
    </div>
  );
}
